@@ -4,10 +4,11 @@ from .augment import *
 from .learner import *
 from .mixup import *
 from ..basics import *
-from ..callback import channelslast, lr_finder, casttotensor, tracker
+from ..callback import channelslast, ema, lr_finder, casttotensor, tracker
 from ..data.all import *
 from ..losses import *
 from ..metrics import *
 from ..multiloss import *
 from ..optimizer.all import *
+from ..schedulers import *
 from ..utils import *
\ No newline at end of file
